
close all

%% Producing the oregingal signal 

% Sampling period
Fs = 500;
% Sampling interval
Ts=1/Fs;
% Length of the signal
N=2000;
% Maximum time
Tmax=(N-1)*Ts;
% Time vector
t=0:Ts:Tmax;
% Main frequencies & phase of the oreginal signal
F1=10;
F2=20;
phi1=1.4;
% Oreginal signal
x=cos(2*pi*F1*t)+0.5*cos(2*pi*F2*t+phi1);
% Plot range 
plot_range =(N/2-100:N/2+100);
% Plot signal in the range
figure(1)
plot(t(plot_range),x(plot_range),'LineWidth',2.5);
axis tight


%% Generate noise in a specific frequency band (12-18 Hz)

% Generate white Gaussian noise 
ns = randn(1,length(x))*3;
% Design and load pass band filter: 12 to 18 Hz
load PB_12_18;
fvtool(PB_12_18)
% Construct in-band noise
ns_filtered=filter(PB_12_18,ns);
% Signal + Noise
x_ns=x+ns_filtered;
% Plot oreginal signal and signal plus noise
figure(3)
plot(t(plot_range),x(plot_range),'LineWidth',2.5);
hold on
plot(t(plot_range),x_ns(plot_range),'LineWidth',2.5);
axis tight



%% single-sided frequency spectrum of the signal plus noise 

% Compute fft
X=fft(x_ns);
% Take abs and scale it
X2=abs(X/N);
% Pick the first half
X1=X2(1:N/2+1);
% Multiply by 2 (except the DC part), to compenseate 
% the removed side from the spectrum.
X1(2:end-1) = 2*X1(2:end-1);
% Frequency range
F = Fs*(0:(N/2))/N;
% Plot single-sided spectrum
figure(4)
plot(F,X1,'LineWidth',2.5) 
title('Single-Sided Amplitude Spectrum')
xlabel('f (Hz)');



%% Remove noise usin band-stop IIR filter

% Design and load IIR band stop filter: 12 to 18 Hz
load SB_12_18
fvtool(SB_12_18)
% Filter the noise out
x_clean_IIR=filter(SB_12_18,x_ns);
% Single sided spectrum of cleaned signal
% Compute fft
X=fft(x_clean_IIR);
% Take abs and scale it
X2=abs(X/N);
% Pick the first half
X1=X2(1:N/2+1);
% Multiply by 2 (except the DC part), to compenseate 
% the removed side from the spectrum.
X1(2:end-1) = 2*X1(2:end-1);
% Frequency range
F = Fs*(0:(N/2))/N;
% Plot single-sided spectrum
figure(6)
plot(F,X1,'LineWidth',2.5) 
title('Single-Sided Amplitude Spectrum')
xlabel('f (Hz)');
figure(7)
plot(t(plot_range),x(plot_range),'LineWidth',2.5);
hold on
plot(t(plot_range),x_clean_IIR(plot_range),'LineWidth',2.5);
axis tight


%% Remove noise usin band-stop FIR filter

% Design and load FIR band stop filter: 12 to 18 Hz
load SB_12_18_FIR
fvtool(SB_12_18_FIR)
% Filter the noise out
x_clean_FIR=filter(SB_12_18_FIR,x_ns);
% Single sided spectrum of cleaned signal
% Compute fft
X=fft(x_clean_FIR);
% Take abs and scale it
X2=abs(X/N);
% Pick the first half
X1=X2(1:N/2+1);
% Multiply by 2 (except the DC part), to compenseate 
% the removed side from the spectrum.
X1(2:end-1) = 2*X1(2:end-1);
% Frequency range
F = Fs*(0:(N/2))/N;
% Plot single-sided spectrum
figure(9)
plot(F,X1,'LineWidth',2.5) 
title('Single-Sided Amplitude Spectrum')
xlabel('f (Hz)');
figure(10)
plot(t(plot_range),x(plot_range),'LineWidth',2.5);
hold on
plot(t(plot_range),x_clean_FIR(plot_range),'LineWidth',2.5);
axis tight

